==> xray_audit-1.2.0.tar.gz: xray_audit/src/Plugin/xray_audit/tasks/QueryGroup/XrayAuditQueryTaskContentEntitiesPlugin.php <==
<?php

namespace Drupal\xray_audit\Plugin\xray_audit\tasks\QueryGroup;

/**
 * Plugin implementation of queries_data_node.
 *
 * @XrayAuditTaskPlugin (
 *   id = "queries_data_content_entities",
 *   label = @Translation("Content Entities reports"),
 *   description = @Translation("Reports on all the content entities of this site."),
 *   group = "queries_data",
 *   sort = 1,
 *   operations = {
 *      "content_entities" = {
 *          "label" = "Content type entities",
 *          "description" = "List of the content type entities of this site (core, contrib and custom)."
 *       }
 *   }
 * )
 */
class XrayAuditQueryTaskContentEntitiesPlugin extends XrayAuditQueryTaskPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getDataOperationResult(string $operation = NULL) {
    switch ($operation) {
      case 'content_entities':
        return $this->contentEntities();
    }
    return [];
  }

  /**
   * Get data for operation "content_entities".
   *
   * @return array
   *   Data.
   */
  protected function contentEntities() {

    $headerTable = [
      $this->t('id'),
      $this->t('Group'),
      $this->t('Provider'),
      $this->t('Class'),
    ];
    $resultTable = [];
    $definitions = $this->entityTypeManager->getDefinitions();
    foreach ($definitions as $key => $definition) {
      $group = $definition->getGroup();
      if ($group !== 'content') {
        continue;
      }
      $resultTable[$key] = [
        'key' => $key,
        'group' => $group,
        'provider' => $definition->getProvider(),
        'class' => $definition->getClass(),
      ];
    }

    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];
  }

}

==> xray_audit-1.5.1.tar.gz: xray_audit/src/Plugin/xray_audit/tasks/QueryGroup/XrayAuditQueryTaskContentEntitiesPlugin.php <==
<?php

namespace Drupal\xray_audit\Plugin\xray_audit\tasks\QueryGroup;

/**
 * Plugin implementation of queries_data_node.
 *
 * @XrayAuditTaskPlugin (
 *   id = "queries_data_content_entities",
 *   label = @Translation("Content Entities reports"),
 *   description = @Translation("Reports on all the content entities of this site."),
 *   group = "queries_data",
 *   sort = 1,
 *   operations = {
 *      "content_entities" = {
 *          "label" = "Content type entities",
 *          "description" = "List of the content type entities of this site
 *            (core, contrib and custom)."
 *       }
 *   }
 * )
 */
class XrayAuditQueryTaskContentEntitiesPlugin extends XrayAuditQueryTaskPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getDataOperationResult(string $operation = NULL) {
    switch ($operation) {
      case 'content_entities':
        return $this->contentEntities();
    }
    return [];
  }

  /**
   * Get data for operation "content_entities".
   *
   * @return array
   *   Data.
   */
  protected function contentEntities() {

    $headerTable = [
      $this->t('id'),
      $this->t('Group'),
      $this->t('Provider'),
      $this->t('Class'),
    ];
    $resultTable = [];
    $definitions = $this->entityTypeManager->getDefinitions();
    foreach ($definitions as $key => $definition) {
      $group = $definition->getGroup();
      if ($group !== 'content') {
        continue;
      }
      $resultTable[$key] = [
        'key' => $key,
        'group' => $group,
        'provider' => $definition->getProvider(),
        'class' => $definition->getClass(),
      ];
    }

    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];
  }

}
